import React, { Component } from 'react';
import './index.scss'
import Question from '../common/question'
import { HeaderBar } from "@common/index"
import { browser, getParam, http } from "@/utils"
import { Toast } from 'antd-mobile'
import { withRouter } from 'react-router-dom'
import storage from 'store2'
import Navigation from "@components/ai-test/common/navigation"

class Exam extends Component {

  store = storage.namespace('aiTestExam')
  timer = null
  unlisten = null

  state = {
    questions: [],
    activeQuestion: 0,
    time: {
      h: 0,
      m: 0,
      s: 0,
    },
    answer: {},
    recordId: undefined,
  }

  componentDidMount() {
    this.getQuestions()
    this.unlisten = this.props.history.listen((location, action) => {
      if (action === 'POP' && location.pathname === '/ai-test/scores') {
        this.unlisten()
        this.store.clearAll()
      }
    })
  }

  setCounter = () => {
    this.timer = setInterval(() => {

      this.setState(state => {
        const time = state.time
        if (time.s + 1 >= 60) {
          time.s = 0
          if (time.m + 1 >= 60) {
            time.h = time.h + 1
            time.m = 0
          } else {
            time.m = time.m + 1
          }
        } else {
          time.s = time.s + 1
        }
        return {
          time,
        }
      })
    }, 1000)
  }

  goBack = () => {
    const {state} = this.props.location
    if (browser.isWeixin && getParam('code') && getParam('state')) {
      window.history.go(-2)
    }
    if (state.records && state.records.length > 1) {
      window.history.go(-1);
    } else if (state.from && state.from.pathname) {
      location.replace(`${state.from.pathname}${state.from.search}`)
    } else {
      window.location.href = window.location.origin
    }
  }

  getQuestions = () => {
    http.get(`${API.home}/sys/get_question`)
      .then(res => {
        const {code, msg, data} = res.data
        if (code === 200) {
          let answer = this.store.get('answer') || {}, time = this.store.get('time')
          if (!answer) {
            data.forEach(item => {
              answer[item.id] = undefined
            })
          }
          if (!time) {
            time = {h: 0, m: 0, s: 0}
          }

          this.setState({
            questions: data,
            answer,
            time,
            recordId: data[0].record_id,
          })

          this.setCounter()
        } else if (code === 23007) {
          this.props.history.replace('/ai-test/scores')
        } else {
          Toast.fail(msg, 2, null, false)
        }
      })
  }

  selectAnswer = (question, optionId) => {
    this.setState(state => {
      const answer = state.answer
      answer[question.id] = optionId
      return {
        answer,
      }
    }, () => {
      const {answer, questions} = this.state
      const keys = Object.keys(answer)
      const values = Object.values(answer)
      if (keys.length === questions.length && values.every(item => item)) {
        const {history} = this.props
        clearInterval(this.timer)
        const {time, answer, recordId} = this.state
        this.store.setAll({time, answer, recordId})
        history.push('/ai-test/submit')
      }
    })
  }

  render() {
    const {questions, activeQuestion, time, answer} = this.state
    return (
      <div className={'exam'}>
        <header>
          <div className="go-back">
            <i className='iconfont iconiconfront-68' onClick={this.goBack}></i>
          </div>
          <div className="time">
            <i className={'iconfont iconzhong'}></i>
            <span>
              {
                !!time.h && <>{time.h && time.h.toString().padStart(2, '0')}:</>
              }
              {time.m.toString().padStart(2, '0')}:
              {time.s.toString().padStart(2, '0')}
            </span>
          </div>
          <div className="count">{Object.values(answer).filter(item => item).length}/{questions.length}</div>
        </header>
        <div className="banner">
          <img src="https://julyedu-cdn.oss-cn-beijing.aliyuncs.com/ai-test/m/scores/exam-banner.png" alt=""/>
        </div>
        <div className="question-section">
          {
            !!questions.length &&
            <Question activeIndex={activeQuestion} question={questions[activeQuestion]} selectAnswer={this.selectAnswer} answer={answer}></Question>
          }
        </div>
        <Navigation questions={questions} answer={answer} handleClick={(index) => {
          this.setState({
            activeQuestion: index,
          });
        }}/>
      </div>
    );
  }
}

export default withRouter(Exam);