import React, { Component } from 'react';
import './index.scss'
import { HeaderBar } from "@common/index"
import storage from 'store2'
import { Toast } from "antd-mobile";
import { http } from "@/utils"

class SubmitAnswer extends Component {

  store = storage.namespace('aiTestExam')

  state = {
    time: this.store.get('time') || {h: 0, m: 0, s: 0},
    answer: this.store.get('answer'),
    recordId: this.store.get('recordId'),
  }

  submit = () => {
    const {answer, recordId} = this.state
    http.post(`${API.home}/sys/submit_answer`, {
      answer: answer,
      cost_time: this.getCostTime(),
      record_id: recordId,
    }).then(res => {
      const {code, msg, data} = res.data
      if (code === 200) {
        this.store.clearAll()
      } else {
        Toast.fail(msg, 2, null, false)
      }
    })
  }

  getCostTime = () => {
    const {time} = this.state
    return parseInt(time.h) * 60 * 60 * 1000 + parseInt(time.m) * 60 * 1000 + parseInt(time.s) * 1000
  }


  render() {
    const {time, answer} = this.state
    return (
      <div className={'submit-answer'}>
        <HeaderBar title={'提交试卷'} arrow={true}/>
        <div className="content">
          <div className="cost">用时：
            <span>
              {
                !!time.h && <>{time.h && time.h.toString().padStart(2, '0')}:</>
              }
              {time.m.toString().padStart(2, '0')}:
              {time.s.toString().padStart(2, '0')}
            </span>
          </div>
          <ul className={'answers'}>
            {
              answer && !!Object.keys(answer).length && Object.keys(answer).map((item, index) => {
                return <li key={item} className={answer[item] ? 'selected' : ''}>{index + 1}</li>
              })
            }
          </ul>
          <button onClick={this.submit}>提交</button>
        </div>
      </div>
    );
  }
}

export default SubmitAnswer;